@@ -25,7 +25,7 @@ The purpose of this module is a validation of the specified
 L<Email Address|https://en.wikipedia.org/wiki/Email_address>.
 
 The core part of the module is written in C and can be
-found L<here|https://github.com/gh0stwizard/libeav>.
+found in the B<libeav> directory.
 
 The module conforms to:
 
@@ -49,17 +49,23 @@ characters without quoted-pairs.
 
 =item *
 
-L<RFC 6531|https://tools.ietf.org/html/rfc6531> and
-L<RFC 20|https://tools.ietf.org/html/rfc20>.
-Allows Internationalized Email Addresses encoded 
-in UTF-8, L<RFC 3629|https://tools.ietf.org/html/rfc3629>.
-
-Currently, this mode based on RFC 5321 and disallow next characters,
-as described in RFC 20: C<`>, C<#>, C<^>, C<{>, C<}>, C<~> and C<|>.
-They must be in double-quotes.
+L<RFC 6531|https://tools.ietf.org/html/rfc6531>
+- allows Internationalized Email Addresses encoded in UTF-8.
+See also L<RFC 3629|https://tools.ietf.org/html/rfc3629>).
+The B<RFC 6531> is based on the rules of the B<RFC 5321>.
 
 =back
 
+You may change the behavior of the B<RFC 6531> mode when
+building the module and enable support of the
+L<RFC 20|https://tools.ietf.org/html/rfc20> and
+L<RFC 5322|https://tools.ietf.org/html/rfc5322>.
+By default, neither B<RFC 5322> nor B<RFC 20> is enabled.
+
+The B<RFC 20> disallows the next characters within local-part:
+C<`>, C<#>, C<^>, C<{>, C<}>, C<~> and C<|>.
+They must be in double-quotes.
+
 The default behavior of the module also includes
 the check of:
 
@@ -76,6 +82,13 @@ FQDN - if the domain contains only alias and it is not
 a special or reserved domain, then the result is negative,
 that is, such an email address is considered as invalid.
 
+=item *
+
+TLD - the module checks that domain is a Top Level Domain (TLD).
+The list of TLDs has been taken from IANA's
+L<Root Zone Database|https://www.iana.org/domains/root/db>.
+See the L</"TLD INFORMATION"> section below for details.
+
 =back
 
 =cut
@@ -108,7 +121,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = ();
 
-our $VERSION = "0.3.0";
+our $VERSION = "0.3.2";
 
 require XSLoader;
 XSLoader::load('EAV::XS', $VERSION);
@@ -223,7 +236,7 @@ The B<allow_tld> option accepts the next values:
 =item *
 
 TLD_NOT_ASSIGNED - allow not assigned TLDs. On IANA website they are listed
-as "Not assigned" in the "Sponsoring Organisation" field.
+as "Not assigned" in the "TLD Manager" field.
 
 =item *
 
@@ -255,7 +268,6 @@ TLD_SPECIAL - allow Special & Restricted TLDs.
 See L<RFC 2606|https://tools.ietf.org/html/rfc2606>,
 L<RFC 6761|https://tools.ietf.org/html/rfc6761> and
 L<RFC 7686|https://tools.ietf.org/html/rfc7686> for details.
-
 Currently, this includes the next TLDs: "test.", "invalid.", 
 "localhost.", "example.", "onion." and also Second Level Domains,
 such as, "example.com.", "example.net." and "example.org.".
@@ -364,5 +376,9 @@ CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+=head1 AVAILABILITY
+
+You can obtain the latest version from
+L<https://github.com/gh0stwizard/p5-EAV-XS/>.
 
 =cut
